@@ -243,7 +243,7 @@ pub async fn reload<P: AsRef<Path>>(
         let path = entry.path();
         info!("load plugin from {:?}", path.display());
         let now = Instant::now();
-        match ExtensionProxy::load(&store, &path) {
+        match ExtensionProxy::load(store, &path) {
             Ok(proxy) => {
                 let source = proxy.detail();
                 info!("loaded in {} ms: {:?}", now.elapsed().as_millis(), source);
@@ -331,7 +331,7 @@ async fn thread_main<P: AsRef<Path>>(path: P, extension_receiver: UnboundedRecei
                     }
                 }
             }
-            Command::Unload(source_id) => {
+            Command::Unload(source_id, tx) => {
                 let extension_path = if let Some((source, _)) = extension_map.get_mut(&source_id) {
                     PathBuf::new()
                         .join(&path)
@@ -360,6 +360,10 @@ async fn thread_main<P: AsRef<Path>>(path: P, extension_receiver: UnboundedRecei
                 if let Err(e) = reload(&path, &store, &mut extension_map).await {
                     error!("error reloading extension: {}", e);
                 }
+
+                if tx.send(()).is_err() {
+                    error!("[Command::Unload] receiver dropped");
+                }
             }
             Command::Exist(source_id, tx) => {
                 let exist = extension_map.get(&source_id).is_some();
